==> emodpy-1.1.0-py3-none-any.whl: tests/test_mirgration.py <==
import os
import pytest
from idmtools.core import ItemType
from idmtools.core.platform_factory import Platform
from idmtools.entities.experiment import Experiment
from idmtools_test.utils.itest_with_persistence import ITestWithPersistence
from examples.config_update_parameters import del_folder

from emodpy.defaults import EMODSir
from emodpy.emod_file import MigrationTypes
from emodpy.emod_task import EMODTask

current_directory = os.path.dirname(os.path.realpath(__file__))
INPUT_PATH = os.path.join(current_directory, "..", "examples", "reporters", "inputs")
BIN_PATH = os.path.join(current_directory, "..", "examples", "inputs", "bin")


@pytest.mark.comps
class TestMigration(ITestWithPersistence):

    def setUp(self) -> None:
        self.case_name = os.path.basename(__file__) + "--" + self._testMethodName
        print(self.case_name)
        self.platform = Platform('COMPS2')

    def test_experiment_local_migrations(self):
        # Create EMODTask with the set of provided files
        task = EMODTask.from_default(default=EMODSir(), eradication_path=os.path.join(BIN_PATH, "Eradication.exe"))

        # Add new demographics
        task.demographics.clear()
        task.demographics.add_demographics_from_file(os.path.join(INPUT_PATH, "3x3_demographics.json"))

        # Add some migrations
        task.migrations.add_migration_from_file(MigrationTypes.LOCAL,
                                                os.path.join(INPUT_PATH, "3x3_Age_Gender_Local.bin"))

        # Create the experiment from task and run
        experiment = Experiment.from_task(task, name=self.case_name)
        self.platform.run_items(experiment)
        self.platform.wait_till_done(experiment)
        self.assertTrue(experiment.succeeded, "expected experiment succeeded")

        # verify migration files added to experiment asset.(COMPS's simluation's Assets/mirgration folder)
        # 1) download Assets/migrations/3x3_Age_Gender_Local.bin from simulation, verify file exists
        # 2) download Assets/migrations/3x3_Age_Gender_Local.bin.json from simulation, validate file exists

        # delete output from previous run
        del_folder("output")
        # create a new empty 'output' dir
        os.mkdir("output")
        filenames = ["Assets/migrations/3x3_Age_Gender_Local.bin", "Assets/migrations/3x3_Age_Gender_Local.bin.json"]

        sims = self.platform.get_children_by_object(experiment)
        for simulation in sims:
            # download files from simulation
            self.platform.get_files_by_id(simulation.id, item_type=ItemType.SIMULATION, files=filenames,
                                          output='output')
            # validate files exist
            local_path = os.path.join("output", str(simulation.uid), "Assets", "migrations")
            self.assertTrue(os.path.exists(os.path.join(local_path, "3x3_Age_Gender_Local.bin")))
            self.assertTrue(os.path.exists(os.path.join(local_path, "3x3_Age_Gender_Local.bin.json")))

==> emodpy-1.19.0.dev8-py3-none-any.whl: tests/test_mirgration.py <==
import os
import pytest
from idmtools.core import ItemType
from idmtools.core.platform_factory import Platform
from idmtools.entities.experiment import Experiment
from idmtools_test.utils.itest_with_persistence import ITestWithPersistence
from examples.config_update_parameters import del_folder

from emodpy.defaults import EMODSir
from emodpy.emod_file import MigrationTypes
from emodpy.emod_task import EMODTask

from emod_api.config import from_schema as fs
from . import manifest

current_directory = os.path.dirname(os.path.realpath(__file__))
INPUT_PATH = os.path.join(current_directory, "..", "examples", "reporters", "inputs")
# BIN_PATH = os.path.join(current_directory, "..", "examples", "inputs", "bin")



@pytest.mark.comps
class TestMigration(ITestWithPersistence):

    def setUp(self) -> None:
        self.case_name = os.path.basename(__file__) + "--" + self._testMethodName
        print(self.case_name)
        self.platform = Platform('SLURM')

    def test_experiment_local_migrations(self):
        # Create EMODTask with the set of provided files
        eradication_path = manifest.eradication_path_linux
        schema_path = manifest.schema_path_linux
        config_file = os.path.join(manifest.config_folder, 'config_local_migrations.json')
        manifest.delete_existing_file(config_file)
        builder = fs.SchemaConfigBuilder(schema_name=schema_path, config_out=config_file)

        task = EMODTask.from_files(config_path=config_file,
                                   campaign_path=None,
                                   demographics_paths=os.path.join(INPUT_PATH, "3x3_demographics.json"),
                                   eradication_path=eradication_path,
                                   ep4_path=manifest.ep4_path)

        # task = EMODTask.from_default(default=EMODSir(), eradication_path=os.path.join(BIN_PATH, "Eradication.exe"))
        # # Add new demographics
        # task.demographics.clear()
        # task.demographics.add_demographics_from_file(os.path.join(INPUT_PATH, "3x3_demographics.json"))

        # Add some migrations
        task.migrations.add_migration_from_file(MigrationTypes.LOCAL,
                                                os.path.join(INPUT_PATH, "3x3_Age_Gender_Local.bin"))

        # Create the experiment from task and run
        experiment = Experiment.from_task(task, name=self.case_name)
        self.platform.run_items(experiment)
        self.platform.wait_till_done(experiment)
        self.assertTrue(experiment.succeeded, "expected experiment succeeded")

        # verify migration files added to experiment asset.(COMPS's simluation's Assets/mirgration folder)
        # 1) download Assets/migrations/3x3_Age_Gender_Local.bin from simulation, verify file exists
        # 2) download Assets/migrations/3x3_Age_Gender_Local.bin.json from simulation, validate file exists

        # delete output from previous run
        del_folder("output")
        # create a new empty 'output' dir
        os.mkdir("output")
        filenames = ["Assets/migrations/3x3_Age_Gender_Local.bin", "Assets/migrations/3x3_Age_Gender_Local.bin.json"]

        sims = self.platform.get_children_by_object(experiment)
        for simulation in sims:
            # download files from simulation
            self.platform.get_files_by_id(simulation.id, item_type=ItemType.SIMULATION, files=filenames,
                                          output='output')
            # validate files exist
            local_path = os.path.join("output", str(simulation.uid), "Assets", "migrations")
            self.assertTrue(os.path.exists(os.path.join(local_path, "3x3_Age_Gender_Local.bin")))
            self.assertTrue(os.path.exists(os.path.join(local_path, "3x3_Age_Gender_Local.bin.json")))


if __name__ == '__main__':
    import unittest
    unittest.main()
